@@ -1,4 +1,4 @@
-// Copyright (C) 2004-2022 Artifex Software, Inc.
+// Copyright (C) 2004-2023 Artifex Software, Inc.
 //
 // This file is part of MuPDF.
 //
@@ -17,8 +17,8 @@
 //
 // Alternative licensing terms are available from the licensor.
 // For commercial licensing, see <https://www.artifex.com/> or contact
-// Artifex Software, Inc., 1305 Grant Avenue - Suite 200, Novato,
-// CA 94945, U.S.A., +1(415)492-9861, for further information.
+// Artifex Software, Inc., 39 Mesa Street, Suite 108A, San Francisco,
+// CA 94129, USA, for further information.
 
 #ifndef MUPDF_PDF_ANNOT_H
 #define MUPDF_PDF_ANNOT_H
@@ -262,11 +262,6 @@ void pdf_walk_tree(fz_context *ctx, pdf_obj *tree, pdf_obj *kid_name,
 int pdf_resolve_link(fz_context *ctx, pdf_document *doc, const char *uri, float *xp, float *yp);
 fz_link_dest pdf_resolve_link_dest(fz_context *ctx, pdf_document *doc, const char *uri);
 
-/*
-	Create a destination object given an internal link URI.
-*/
-pdf_obj *pdf_new_destination_from_link(fz_context *ctx, pdf_document *doc, const char *uri);
-
 /*
 	Create an action object given a link URI. The action will
 	be a GoTo or URI action depending on whether the link URI
@@ -274,6 +269,19 @@ pdf_obj *pdf_new_destination_from_link(fz_context *ctx, pdf_document *doc, const
 */
 pdf_obj *pdf_new_action_from_link(fz_context *ctx, pdf_document *doc, const char *uri);
 
+/*
+	Create a destination object given a link URI expected to adhere
+	to the Adobe specification "Parameters for Opening PDF files"
+	from the Adobe Acrobat SDK. The resulting destination object
+	will either be a PDF string, or a PDF array referring to a page
+	and suitable zoom level settings. In the latter case the page
+	can be referred to by PDF object number or by page number, this
+	is controlled by the is_remote argument. For remote destinations
+	it is not possible to refer to the page by object number, so
+	page numbers are used instead.
+*/
+pdf_obj *pdf_new_dest_from_link(fz_context *ctx, pdf_document *doc, const char *uri, int is_remote);
+
 /*
 	Create a link URI string according to the Adobe specification
 	"Parameters for Opening PDF files" from the Adobe Acrobat SDK,
@@ -283,19 +291,45 @@ pdf_obj *pdf_new_action_from_link(fz_context *ctx, pdf_document *doc, const char
 
 	The resulting string must be freed by the caller.
 */
-char *pdf_format_link_uri(fz_context *ctx, fz_link_dest dest);
+char *pdf_new_uri_from_explicit_dest(fz_context *ctx, fz_link_dest dest);
 
 /*
-	Parse an internal link URI that uses the Adobe specification
-	"parameters for opening PDF files".
+	Create a remote link URI string according to the Adobe specification
+	"Parameters for Opening PDF files" from the Adobe Acrobat SDK,
+	version 8.1, which can, at the time of writing, be found here:
+
+	https://web.archive.org/web/20170921000830/http://www.adobe.com/content/dam/Adobe/en/devnet/acrobat/pdfs/pdf_open_parameters.pdf
+
+	The file: URI scheme is used in the resulting URI if the remote document
+	is specified by a system independent path (already taking the recommendations
+	in table 3.40 of the PDF 1.7 specification into account), and either a
+	destination name or a page number and zoom level are appended:
+	file:///path/doc.pdf#page=42&view=FitV,100
+	file:///path/doc.pdf#nameddest=G42.123456
+
+	If a URL is used to specify the remote document, then its scheme takes
+	precedence and either a destination name or a page number and zoom level
+	are appended:
+	ftp://example.com/alpha.pdf#page=42&view=Fit
+	https://example.com/bravo.pdf?query=parameter#page=42&view=Fit
+
+	The resulting string must be freed by the caller.
 */
-fz_link_dest pdf_parse_link_uri(fz_context *ctx, const char *uri);
+char *pdf_append_named_dest_to_uri(fz_context *ctx, const char *url, const char *name);
+char *pdf_append_explicit_dest_to_uri(fz_context *ctx, const char *url, fz_link_dest dest);
+char *pdf_new_uri_from_path_and_named_dest(fz_context *ctx, const char *path, const char *name);
+char *pdf_new_uri_from_path_and_explicit_dest(fz_context *ctx, const char *path, fz_link_dest dest);
 
 /*
 	Create transform to fit appearance stream to annotation Rect
 */
 fz_matrix pdf_annot_transform(fz_context *ctx, pdf_annot *annot);
 
+/*
+	Create a new link object.
+*/
+fz_link *pdf_new_link(fz_context *ctx, pdf_page *page, fz_rect rect, const char *uri, pdf_obj *obj);
+
 /*
 	create a new annotation of the specified type on the
 	specified page. The returned pdf_annot structure is owned by the
@@ -309,6 +343,26 @@ pdf_annot *pdf_create_annot_raw(fz_context *ctx, pdf_page *page, enum pdf_annot_
 */
 fz_link *pdf_create_link(fz_context *ctx, pdf_page *page, fz_rect bbox, const char *uri);
 
+/*
+	delete an existing link from the specified page.
+*/
+void pdf_delete_link(fz_context *ctx, pdf_page *page, fz_link *link);
+
+enum pdf_border_style
+{
+	PDF_BORDER_STYLE_SOLID = 0,
+	PDF_BORDER_STYLE_DASHED,
+	PDF_BORDER_STYLE_BEVELED,
+	PDF_BORDER_STYLE_INSET,
+	PDF_BORDER_STYLE_UNDERLINE,
+};
+
+enum pdf_border_effect
+{
+	PDF_BORDER_EFFECT_NONE = 0,
+	PDF_BORDER_EFFECT_CLOUDY,
+};
+
 /*
 	create a new annotation of the specified type on the
 	specified page. Populate it with sensible defaults per the type.
@@ -339,6 +393,11 @@ void pdf_delete_annot(fz_context *ctx, pdf_page *page, pdf_annot *annot);
 void pdf_set_annot_popup(fz_context *ctx, pdf_annot *annot, fz_rect rect);
 fz_rect pdf_annot_popup(fz_context *ctx, pdf_annot *annot);
 
+/*
+	Check to see if an annotation has a rect.
+*/
+int pdf_annot_has_rect(fz_context *ctx, pdf_annot *annot);
+
 /*
 	Check to see if an annotation has an ink list.
 */
@@ -369,6 +428,16 @@ int pdf_annot_has_interior_color(fz_context *ctx, pdf_annot *annot);
 */
 int pdf_annot_has_line_ending_styles(fz_context *ctx, pdf_annot *annot);
 
+/*
+	Check to see if an annotation has a border.
+*/
+int pdf_annot_has_border(fz_context *ctx, pdf_annot *annot);
+
+/*
+	Check to see if an annotation has a border effect.
+*/
+int pdf_annot_has_border_effect(fz_context *ctx, pdf_annot *annot);
+
 /*
 	Check to see if an annotation has an icon name.
 */
@@ -399,6 +468,36 @@ fz_rect pdf_annot_rect(fz_context *ctx, pdf_annot *annot);
 */
 float pdf_annot_border(fz_context *ctx, pdf_annot *annot);
 
+/*
+	Retrieve the annotation border style.
+ */
+enum pdf_border_style pdf_annot_border_style(fz_context *ctx, pdf_annot *annot);
+
+/*
+	Retrieve the annotation border width in points.
+ */
+float pdf_annot_border_width(fz_context *ctx, pdf_annot *annot);
+
+/*
+	How many items does the annotation border dash pattern have?
+ */
+int pdf_annot_border_dash_count(fz_context *ctx, pdf_annot *annot);
+
+/*
+	How long is dash item i in the annotation border dash pattern?
+ */
+float pdf_annot_border_dash_item(fz_context *ctx, pdf_annot *annot, int i);
+
+/*
+	Retrieve the annotation border effect.
+ */
+enum pdf_border_effect pdf_annot_border_effect(fz_context *ctx, pdf_annot *annot);
+
+/*
+	Retrieve the annotation border effect intensity.
+ */
+float pdf_annot_border_effect_intensity(fz_context *ctx, pdf_annot *annot);
+
 /*
 	Retrieve the annotation opacity. (0 transparent, 1 solid).
 */
@@ -465,16 +564,53 @@ fz_point pdf_annot_ink_list_stroke_vertex(fz_context *ctx, pdf_annot *annot, int
 */
 void pdf_set_annot_flags(fz_context *ctx, pdf_annot *annot, int flags);
 
+/*
+	Set the stamp appearance stream to a custom image.
+	Fits the image to the current Rect, and shrinks the Rect
+	to fit the image aspect ratio.
+*/
+void pdf_set_annot_stamp_image(fz_context *ctx, pdf_annot *annot, fz_image *image);
+
 /*
 	Set the bounding box for an annotation, in doc space.
 */
 void pdf_set_annot_rect(fz_context *ctx, pdf_annot *annot, fz_rect rect);
 
 /*
-	Set the border width for an annotation, in points.
+	Set the border width for an annotation, in points and remove any border effect.
 */
 void pdf_set_annot_border(fz_context *ctx, pdf_annot *annot, float width);
 
+/*
+	Set the border style for an annotation.
+*/
+void pdf_set_annot_border_style(fz_context *ctx, pdf_annot *annot, enum pdf_border_style style);
+
+/*
+	Set the border width for an annotation in points;
+*/
+void pdf_set_annot_border_width(fz_context *ctx, pdf_annot *annot, float width);
+
+/*
+	Clear the entire border dash pattern for an annotation.
+*/
+void pdf_clear_annot_border_dash(fz_context *ctx, pdf_annot *annot);
+
+/*
+	Add an item to the end of the border dash pattern for an annotation.
+*/
+void pdf_add_annot_border_dash_item(fz_context *ctx, pdf_annot *annot, float length);
+
+/*
+	Set the border effect for an annotation.
+*/
+void pdf_set_annot_border_effect(fz_context *ctx, pdf_annot *annot, enum pdf_border_effect effect);
+
+/*
+	Set the border effect intensity for an annotation.
+*/
+void pdf_set_annot_border_effect_intensity(fz_context *ctx, pdf_annot *annot, float intensity);
+
 /*
 	Set the opacity for an annotation, between 0 (transparent) and 1
 	(solid).
@@ -573,6 +709,7 @@ void pdf_set_annot_line_ending_styles(fz_context *ctx, pdf_annot *annot, enum pd
 
 const char *pdf_annot_icon_name(fz_context *ctx, pdf_annot *annot);
 int pdf_annot_is_open(fz_context *ctx, pdf_annot *annot);
+int pdf_annot_is_standard_stamp(fz_context *ctx, pdf_annot *annot);
 
 void pdf_annot_line(fz_context *ctx, pdf_annot *annot, fz_point *a, fz_point *b);
 void pdf_set_annot_line(fz_context *ctx, pdf_annot *annot, fz_point a, fz_point b);
@@ -735,10 +872,8 @@ fz_buffer *pdf_load_embedded_file_contents(fz_context *ctx, pdf_obj *fs);
 */
 int pdf_verify_embedded_file_checksum(fz_context *ctx, pdf_obj *fs);
 
-char *pdf_parse_link_dest(fz_context *ctx, pdf_document *doc, pdf_obj *obj);
-char *pdf_parse_link_action(fz_context *ctx, pdf_document *doc, pdf_obj *obj, int pagenum);
 pdf_obj *pdf_lookup_dest(fz_context *ctx, pdf_document *doc, pdf_obj *needle);
-fz_link *pdf_load_link_annots(fz_context *ctx, pdf_document *, pdf_obj *annots, int pagenum, fz_matrix page_ctm);
+fz_link *pdf_load_link_annots(fz_context *ctx, pdf_document *, pdf_page *, pdf_obj *annots, int pagenum, fz_matrix page_ctm);
 
 void pdf_annot_MK_BG(fz_context *ctx, pdf_annot *annot, int *n, float color[4]);
 void pdf_annot_MK_BC(fz_context *ctx, pdf_annot *annot, int *n, float color[4]);
@@ -770,4 +905,17 @@ pdf_obj *pdf_annot_filespec(fz_context *ctx, pdf_annot *annot);
 */
 void pdf_set_annot_filespec(fz_context *ctx, pdf_annot *annot, pdf_obj *obj);
 
+/*
+	Get/set a hidden flag preventing the annotation from being
+	rendered when it is being edited. This flag is independent
+	of the hidden flag in the PDF annotation object described in the PDF specification.
+*/
+int pdf_annot_hidden_for_editing(fz_context *ctx, pdf_annot *annot);
+void pdf_set_annot_hidden_for_editing(fz_context *ctx, pdf_annot *annot, int hidden);
+
+/*
+ * Apply Redaction annotation by redacting page underneath and removing the annotation.
+ */
+int pdf_apply_redaction(fz_context *ctx, pdf_annot *annot, pdf_redact_options *opts);
+
 #endif
